scanproject

package
v0.9.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 15, 2024 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Options

type Options struct {
	ProjectNumber   int
	Interval        time.Duration
	DisableComments bool
	FromStatus      string
	ToStatus        string
}

type Scanner

type Scanner struct {
	Options
	// contains filtered or unexported fields
}

func NewScanner

func NewScanner(log logger.Logger, client client.Client, opts Options) *Scanner

func (*Scanner) ScanIssues

func (c *Scanner) ScanIssues(ctx context.Context) error

ScanIssues checks if any issues of a project should be moved into a different column based on ToStatus.

Jump to